Specify image entry in linker script

At present, the entry point for each BL image is specified via the
Makefiles and provided on the command line to the linker. When using a
link script the entry point should rather be specified via the ENTRY()
directive in the link script.

This patch updates linker scripts of all BL images to specify the entry
point using the ENTRY() directive. It also removes the --entry flag
passed to the linker through Makefile.

Fixes issue ARM-software/tf-issues#66

Change-Id: I1369493ebbacea31885b51185441f6b628cf8da0
diff --git a/bl1/aarch64/bl1_entrypoint.S b/bl1/aarch64/bl1_entrypoint.S
index 197eac0..8d12045 100644
--- a/bl1/aarch64/bl1_entrypoint.S
+++ b/bl1/aarch64/bl1_entrypoint.S
@@ -30,19 +30,19 @@
 
 #include <arch.h>
 
-	.globl	reset_handler
+	.globl	bl1_entrypoint
 
 
 	.section	.text, "ax"; .align 3
 
 	/* -----------------------------------------------------
 	 * reset_handler() is the entry point into the trusted
 	 * firmware code when a cpu is released from warm or
 	 * cold reset.
 	 * -----------------------------------------------------
 	 */
 
-reset_handler: ; .type reset_handler, %function
+bl1_entrypoint: ; .type bl1_entrypoint, %function
 	/* ---------------------------------------------
 	 * Perform any processor specific actions upon
 	 * reset e.g. cache, tlb invalidations etc.
@@ -30,19 +30,19 @@
 
 	/* -----------------------------------------------------
-	 * reset_handler() is the entry point into the trusted
+	 * bl1_entrypoint() is the entry point into the trusted
 	 * firmware code when a cpu is released from warm or
 	 * cold reset.